import os
from .evaljs import evaljs

BABEL_COMPILER = os.path.join(os.path.dirname(__file__), 'babel-4.6.6.min.js')


def babel_compile(source):
    """Compiles the given ``source`` from ES6 to ES5 usin Babeljs"""
    with open(BABEL_COMPILER, 'r') as babel_js:
        return evaljs(
            (babel_js.read(),
             'babel.transform(dukpy.es6code).code'),
            es6code=source
        )



import json
from . import _dukpy

try:
    from collections.abc import Iterable
except ImportError:
    from collections import Iterable

try:
    unicode
    string_types = (str, unicode)
except NameError:
    string_types = (bytes, str)


def evaljs(code, **kwargs):
    """Evaluates the given ``code`` as JavaScript and returns the result"""
    jsvars = json.dumps(kwargs)
    jscode = code

    if not isinstance(code, string_types):
        jscode = ';\n'.join(code)

    res = _dukpy.eval_string(jscode, jsvars)
    if res is None:
        return None

    return json.loads(res.decode('utf-8'))



import os
from distutils.core import setup, Extension


duktape = Extension('dukpy._dukpy',
                    define_macros=[('DUK_OPT_DEEP_C_STACK', '1')],
                    sources=[os.path.join('duktape', 'duktape.c'), 
                             'pyduktape.c'],
                    include_dirs=[os.path.join('.', 'duktape')])

setup(
    name='dukpy',
    version='0.0.1',
    description='Simple JavaScript interpreter for Python',
    packages=['dukpy'],
    ext_modules=[duktape],
    package_data={
        'dukpy': ['*.js'],
    }
)
